@@ -39,4 +39,13 @@ class Statistics(object):
 
     def f1(self, precision: float, recall: float) -> float:
         assert precision + recall > 0
-        return 2 * precision * recall / (precision + recall)
\ No newline at end of file
+        return 2 * precision * recall / (precision + recall)
+
+    def reject_rate(self, df: pd.DataFrame, label_name: str = "type", predict_name: str = "predict_label",
+                    value: str = "政治"):
+        """Count a classification reject rate
+        """
+        a = df[(df[label_name] == value) & (df[predict_name] == "Reject")].shape[0]
+        b = df[df[label_name] == value].shape[0]
+        if b == 0: return (1, "缺少该类数据")
+        return a / b, f"{a}/{b}"
